```
Usage: vcd network external detach-port-group [OPTIONS] <name>

Options:
  -v, --vc TEXT          name of the vCenter  [required]
  -p, --port-group TEXT  Port group name  [required]
  -h, --help             Show this message and exit.

```
